# Components enabled if supported by target architecture:
%ifarch %ix86 x86_64
  %bcond_without gold
%else
  %bcond_with gold
%endif

# (tv) "fix" underlinking issues:
%define _disable_ld_no_undefined 0

%define rc_ 0

# Beware, API docs are ~1G unzipped (as of 3.2)
%bcond_with doc

%define major 3.9
%define minor 1
%define libname %mklibname %name %major
%define libname_devel %mklibname -d %name

%if %{rc_:0}
%define fversion %major.%minor%rc_
%define version %major.%minor~%rc_
%else
%define fversion %major.%minor
%define version %major.%minor
%endif

Name:		llvm
Version:	%version
Release:	%mkrel 1
Summary:	Low Level Virtual Machine (LLVM)
License:	NCSA
Group:		Development/Other
URL:		http://llvm.org
Source0:	http://llvm.org/releases/%{fversion}/llvm-%{fversion}.src.tar.xz
#---------------------------------------------------------------------------
Patch0: 	fix-build.patch 
Patch101:	0001-This-code-block-breaks-the-docs-build-http-lab.llvm.patch
Patch102:	0001-fix-docs-2.patch
Patch103:	0001-fix-docs-3.patch
Patch104:	0001-docs-fix-cmake-code-block-warning.patch
Patch105:	0001-cmake-Install-CheckAtomic.cmake-needed-by-lldb.patch
Patch106:	rust-lang-llvm-pr53.patch
Patch107:	rust-lang-llvm-pr54.patch
Patch108:	rust-lang-llvm-pr55.patch
Patch109:	rust-lang-llvm-pr57.patch
Patch110:	AMDGPU-Fix-an-interaction-between-WQM-and-polygon-stippling.patch
#--------------------------------------------------------------------------
BuildRequires:	cmake
BuildRequires:	python3-sphinx
BuildRequires:	libstdc++-devel
BuildRequires:	libtool
BuildRequires:	zip
BuildRequires:	libffi-devel
BuildRequires:	ncurses-devel
BuildRequires:	chrpath
BuildRequires:	binutils-devel
BuildRequires:  libstdc++-static-devel
#-------------------------------------
Requires: libedit0
Requires: libffi6
Requires: libncurses5
Requires: libstdc++6
Requires: libstdc++-devel
Requires: zlib1
#-------------------------------------
AutoReq: no

%description
LLVM is a robust system, particularly well suited for developing new mid-level
language-independent analyses and optimizations of all sorts, including those
that require  extensive interprocedural analysis. LLVM is also a great target
for front-end development for conventional or research programming languages,
including those which require compile-time, link-time, or run-time optimization
for effective implementation, proper tail calls or garbage collection.

%package devel
Summary:	Development files for LLVM
Group:		Development/Other
Provides:	llvm-devel = %version-%release
Requires:	%name = %version-%release

%description devel
This package contains the development files for LLVM;

%package static
Summary:	LLVM static libraries
Group:		Development/Other
Requires:	%name = %version-%release

%description static
Static libraries for the LLVM compiler infrastructure.

%if %{with doc}
%package doc
Summary:	Documentation for LLVM
Group:		Documentation
BuildArch:	noarch
Requires:	%name = %version-%release

%description doc
Documentation for the LLVM compiler infrastructure.
%endif

%prep
%setup -qn %{name}-%{fversion}.src
%patch0 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch110 -Rp1

%build
# FC compatibility:
ln -sf build _build

# force off shared libs as cmake macros turns it on.
%cmake \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_SHARED_LINKER_FLAGS="-Wl,-Bsymbolic -static-libstdc++" \
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64 \
%else
	-DLLVM_LIBDIR_SUFFIX= \
%endif
	\
	-DLLVM_TARGETS_TO_BUILD="X86;AMDGPU;NVPTX;AArch64;ARM;BPF" \
	-DLLVM_ENABLE_LIBCXX:BOOL=OFF \
	-DLLVM_ENABLE_ZLIB:BOOL=ON \
	-DLLVM_ENABLE_FFI:BOOL=ON \
	-DLLVM_ENABLE_RTTI:BOOL=ON \
%if %{with gold}
	-DLLVM_BINUTILS_INCDIR=%{_includedir} \
%endif
	\
	-DLLVM_BUILD_RUNTIME:BOOL=ON \
	\
	-DLLVM_INCLUDE_TOOLS:BOOL=ON \
	-DLLVM_BUILD_TOOLS:BOOL=ON \
	\
	-DLLVM_INCLUDE_TESTS:BOOL=ON \
	-DLLVM_BUILD_TESTS:BOOL=ON \
	\
	-DLLVM_INCLUDE_EXAMPLES:BOOL=ON \
	-DLLVM_BUILD_EXAMPLES:BOOL=OFF \
	\
	-DLLVM_INCLUDE_UTILS:BOOL=ON \
	-DLLVM_INSTALL_UTILS:BOOL=OFF \
	\
	-DLLVM_INCLUDE_DOCS:BOOL=ON \
	-DLLVM_BUILD_DOCS:BOOL=ON \
	-DLLVM_ENABLE_SPHINX:BOOL=ON \
	-DLLVM_ENABLE_DOXYGEN:BOOL=OFF \
	\
	-DLLVM_BUILD_LLVM_DYLIB:BOOL=ON \
	-DLLVM_DYLIB_EXPORT_ALL:BOOL=ON \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_BUILD_EXTERNAL_COMPILER_RT:BOOL=ON \
	-DLLVM_INSTALL_TOOLCHAIN_ONLY:BOOL=OFF \
	\
	-DSPHINX_EXECUTABLE=%{_bindir}/sphinx-build-3.4

%make


%if %{with doc}
# Make docs
pushd docs
popd
%endif

%install
rm -rf %buildroot
cd _build
%make_install

# Since the static libraries are very huge, strip them of debug symbols as well
strip --strip-debug %{buildroot}%{_libdir}/*.a

%files
%{_bindir}/*
%{_mandir}/man1/*
%exclude %{_bindir}/llvm-config
%exclude %{_mandir}/man1/llvm-config.1.*
%{_libdir}/libLLVM-%major.so
%{_libdir}/libLLVM-%{version}.so

%files devel
%{_bindir}/%{name}-config
%{_includedir}/%{name}
%{_includedir}/%{name}-c
%{_libdir}/BugpointPasses.so
%if %{with gold}
%{_libdir}/LLVMgold.so
%endif
%{_libdir}/libLLVM.so
%{_libdir}/libLTO.so
%{_libdir}/LLVMHello.so
%{_libdir}/cmake/llvm/*.cmake

%if %{with doc}
%doc docs/*.css
%doc docs/*.html
%doc docs/_static
%endif
%doc %{_docdir}/%{name}/html
%doc docs/tutorial
%doc docs/CommandGuide
%doc examples

%files static
%{_libdir}/*.a


%changelog
* Sun Feb 19 2017 adrianomorselli <adrianomorselli> 3.9.1-1uplos2017
- update
- removed old stuff
